#!/bin/bash

# Copied and modified from create-dmg/gedit
#gedit approach with preformatted template does not work well - creates dmg with two volumes inside

function do_strip {
    tp=$(file -b --mime-type "$1")

    if [ "$tp" != "application/octet-stream" ]; then
        return
    fi

    name=$(mktemp -t bundle)
    st=$(stat -f %p "$1")
    
    strip -o "$name" -S "$1"
    mv -f "$name" "$1"

    chmod "$st" "$1"
    chmod u+w "$1"
}

pushd $(dirname $0) &>/dev/null

# Strip debug symbols
for i in $(find -E Bluefish.app/Contents/Resources -type f -regex '.*\.(so|dylib)$'); do
    do_strip "$i"
done

do_strip Bluefish.app/Contents/MacOS/bluefish-bin

VOLUME_NAME=Bluefish_MacOSX
DMG_APP=Bluefish.app
MOUNT_DIR="/Volumes/Bluefish"

if [ "$1x" = "x" ]; then
	DMG_FILE=$VOLUME_NAME.dmg
else
	DMG_FILE=$1.dmg
fi

# If images exist remove it
test -f tmp.dmg && rm -f tmp.dmg
test -f $DMG_FILE && rm -f $DMG_FILE

if [ -f "$DMG_APP/.DS_Store" ]; then
    echo "Deleting any .DS_Store in source folder"
    rm "$DMG_APP/.DS_Store"
fi

# Create the image
echo "Making new image..."

# Compute an approximated image size in MB, and bloat by 15 MB
image_size=$(du -ck $DMG_APP | tail -n1 | cut -f1)
image_size=$((($image_size + 15000) / 1000))

echo "Creating disk image (${image_size}MB)..."
hdiutil create -srcfolder "$DMG_APP" -volname Bluefish -fs HFS+ -fsargs "-c c=64,a=16,e=16" -format UDRW -size ${image_size}m tmp.dmg

# try unmount dmg if it was mounted previously (e.g. developer mounted dmg, installed app and forgot to unmount it)
echo "Unmounting any currently mounted disk image with the same name..."
DEV_NAME=$(hdiutil info | egrep '^/dev/' | sed 1q | awk '{print $1}')
test -d "${MOUNT_DIR}" && hdiutil detach "${DEV_NAME}"

# mount it
echo "Mount directory: $MOUNT_DIR"
DEV_NAME=$(hdiutil attach -readwrite -noverify -noautoopen tmp.dmg | egrep '^/dev/' | sed 1q | awk '{print $1}')
echo "Device name:     $DEV_NAME"

# We might get background image one day...
#if ! test -z "$BACKGROUND_FILE"; then
#  echo "Copying background file..."
#  test -d "$MOUNT_DIR/.background" || mkdir "$MOUNT_DIR/.background"
#  cp "$BACKGROUND_FILE" "$MOUNT_DIR/.background/$BACKGROUND_FILE_NAME"
#fi

echo "making link to Applications dir"
ln -s /Applications "$MOUNT_DIR/Applications"

echo "Copying volume icon file ..."
if test -f bluefish.icns; then
cp bluefish.icns "$MOUNT_DIR/.VolumeIcon.icns"
SetFile -c icnC "$MOUNT_DIR/.VolumeIcon.icns"
SetFile -a C "$MOUNT_DIR"
else
echo "volume icon file not found"
fi

# make sure it's not world writeable
echo "Fixing permissions..."
chmod -Rf go-w "${MOUNT_DIR}" &> /dev/null || true
echo "Done fixing permissions."

# make the top window open itself on mount:
echo "Blessing started"
bless --folder "${MOUNT_DIR}" --openfolder "${MOUNT_DIR}"
echo "Blessing finished"

# unmount
echo "Unmounting disk image..."
hdiutil detach "${DEV_NAME}"

# compress image
echo "Compressing disk image..."
hdiutil convert -verbose -format UDBZ -o $DMG_FILE tmp.dmg

echo "Removing source files"
rm -f tmp.dmg
rm -rf $DMG_APP

echo "Disk image done"
popd &>/dev/null

